#
# spec file for package corebird
#
# Copyright (c) 2015 SUSE LINUX GmbH, Nuernberg, Germany.
# Copyright (c) 2013-2014 Dominique Leuenberger, Amsterdam, The Netherlands.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           corebird
Version:        1.0.1
Release:        8.19
Summary:        A lightweight Twitter Client
License:        GPL-3.0+
Group:          Productivity/Networking/Other
Url:            http://corebird.baedert.org/
#Source:        https://github.com/baedert/corebird/archive/%%{version}.tar.gz
Source0:        %{name}-%{version}.tar.gz
BuildRequires:  intltool
BuildRequires:  libtool
BuildRequires:  update-desktop-files
BuildRequires:  vala-devel >= 0.21.1
BuildRequires:  pkgconfig(gdk-x11-3.0)
BuildRequires:  pkgconfig(gee-0.8)
BuildRequires:  pkgconfig(gio-2.0)
BuildRequires:  pkgconfig(glib-2.0) >= 2.40
BuildRequires:  pkgconfig(gstreamer-video-1.0)
BuildRequires:  pkgconfig(gtk+-3.0) >= 3.14
BuildRequires:  pkgconfig(json-glib-1.0)
BuildRequires:  pkgconfig(libnotify)
BuildRequires:  pkgconfig(libsoup-2.4)
BuildRequires:  pkgconfig(rest-0.7)
BuildRequires:  pkgconfig(sqlite3)
Recommends:     %{name}-lang
BuildRoot:      %{_tmppath}/%{name}-%{version}-build

%description
Native Twitter client, integrating into GNOME 3.

%lang_package
%prep
%setup -q

%build
NOCONFIGURE=1 ./autogen.sh
%configure
make %{?_smp_mflags}

%install
%make_install
%suse_update_desktop_file org.baedert.corebird X-SuSE-Core-Internet
%find_lang %{name} %{?no_lang_C}

%post
%glib2_gsettings_schema_post
%icon_theme_cache_post
%desktop_database_post

%postun
%glib2_gsettings_schema_postun
%icon_theme_cache_postun
%desktop_database_postun

%files
%defattr(-,root,root)
%doc COPYING
%{_bindir}/%{name}
%{_datadir}/%{name}/
%dir %{_datadir}/appdata
%{_datadir}/appdata/org.baedert.corebird.appdata.xml
%{_datadir}/applications/org.baedert.corebird.desktop
%{_datadir}/dbus-1/services/org.baedert.corebird.service
%{_datadir}/glib-2.0/schemas/org.baedert.corebird.gschema.xml
%{_datadir}/icons/hicolor/
%{_mandir}/man1/%{name}.1%{?ext_man}

%files lang -f %{name}.lang

%changelog
* Mon Aug  3 2015 lmouillart@gmail.com
- Update to version 1.0.1:
  + Fix show-window action parameter.
  + Fix load lists.
  + Fix black screen instead of playback with 1.0.
* Sat Jun 20 2015 lmouillart@gmail.com
- Update to version 1.0:
  + All dialogs now use client-side decorations if the environment
    dictates it, otherwise they fall back to server-side
    decorations (compose dialog is excluded).
  + Many layout updates
  + The compose window now allows for up to 4 pictures to be
    uploaded.
  + Now save additional information about the account which makes
    it possible for blocked users to be actually blocked,
    i.e. streamed tweets won’t appear in your timeline anymore.
  + When (un)following someone, now also correctly show/hide
    their retweets in the stream.
  + The DM page now sorts threads with unread messages first.
  + The @handle completion known from the compose window is
    now also available when composing Direct Messages,
    as well as in the account settings for the description.
  + Everything app-specific should now be hidpi ready,
    the only thing missing are assets loaded from Twitter
    directly, i.e. avatars and media.
  + Notifications should now get withdrawn whenever it makes sense,
    i.e. if you read a Direct Message before dismissing the
    notification, it should get withdrawn automatically.
  + The hover buttons moved to a right-click menu on every tweet.
  + Plurals are properly localized.
  + We now also respect muted users (even though there’s no UI to
    mute someone)
  + A user’s verification status is now also shown in the tweet
    info page.
  + Everything should now work when the user’s @handle
    (aka screen_name) changes.
  + Switching to the same page (i.e. going to a profile from the
    profile page) now works much better, including the swipe
    transition as well as proper equality checking.
  + Invalid inline media (file size too big, 404, …) should now
    be properly detected and reacted upon (i.e. remove the widget
    in the stream, add the link back).
  + Underlines in @handles are now properly displayed in the app
    menu (i.e. the “open account” submenu)
  + Animated gifs from Twitter are now also handled (just like
    other videos).
  + Tweets in timelines are now single-click activated. This
    unifies the behavior with all other lists in the application.
    Since this interferes with certain user behaviors, there’s a
    setting to switch back to double-click activation.
  + Based on a user’s protection status, we now disable (or hide)
    retweet buttons of tweets.
* Wed Dec 24 2014 zaitor@opensuse.org
- Update to version 0.9:
  + Mentions, hashtags and links now get highlighted directly in
    the compose window.
  + The avatar of the currently active account in a window is now
    clickable, showing all configured accounts.
  + The logic for autostarting accounts is more explicit now.
  + The setting regarding the dark theme is gone (existing
    configurations will keep working).
  + When viewing an image of a tweet with multiple images/videos
    attached, you can now use the cursor keys to navigate between
    them.
  + Avatars in tweets and profiles now show if the user is
    verified.
  + Lots of the application should now react better to missing
    network connections.
  + The activity indicator for loading older tweets is now in the
    tweet list itself.
  + Some things now get immediately applied instead of needing a
    restart of the client.
  + Each window now has a back button, additionally to all the
    keyboard shortcuts available for going back and forward.
  + Last but not least, large parts of the UI have been refined,
    spacing, icons, etc. have been changed.
- Drop corebird-fix-binding-usage.patch and
  corebird-fix-manpage-install.patch: Fixed upstream.
* Mon Sep  8 2014 dimstar@opensuse.org
- Update to version 0.8:
  + Switch build system from cmake to automake.
  + Internal code reorganisation.
  + Add test units.
  + Updated translations.
- Enable make check in %%check section.
- Replace cmake call with autogen.sh (tarball is not bootstrapped)
  and configure.
- Add libtool BuildRequires: needed in order to run autogen.sh.
- Drop cmake BuildRequires: no longer needed after the switch to
  automake.
- Add pkgconfig(gstreamer-video-1.0) and pkgconfig(gdk-x11-3.0)
  BuildRequires: new dependencies.
- Add corebird-fix-binding-usage.patch: Fix usage of bindings.
- Add corebird-fix-manpage-install.patch: Fix man page
  installation.
* Wed Apr 30 2014 malcolmlewis@opensuse.org
- Updated to version 0.7:
  + Regex-based filters are implemented, i.e. you can hide tweets
    you don't want to see.
  + With the introduction of filters, individual users can now also
    be blocked.
  + Replying to tweets now correctly mentions all the users
    mentioned in the original tweet.
  + There's now a favorite timeline, showing all the tweets you
    have favorited.
  + The compose window now completes user names whenever the user
    writes an @.
  + Open windows are now correctly saved on application quit.
  + Tons of refactoring to ensure future progress.
  + Fixed Bugs:
  * #99 - Reorganize the settings dialog.
  * #93 - Feature Request: Add UI for starred tweets.
  * #102 - Remember location of the settings dialog.
  * #107 - Clicking the name link on a "retweeted by" tweet does
    nothing.
  * #108 - Corebird needs a Manpage.
  * #105 - corebird segfaults when using newer versions of glib2
    (2.39.2).
  * #103 - Unfaving a favourited tweet in the favourited list
    disables the tweet.
  * #97 - Reply to all.
  * #117 - Following someone turns on mobile notifications.
  * #126 - Links in DM preview texts are wrong.
  * #4 - How to translate it into other language, such as zh_CN.
  * #41 - Add posibility to mute some content.
  * #56 - Tab Completion for Users and Hashtags.
  + Updated translations.
* Thu Feb  6 2014 malcolmlewis@opensuse.org
- Updated to version 0.6.1:
  + Always show the settings dialog on startup if no startup
    accounts are set. Previously, this broke the very first start
    where org.baedert.corebird.startup-account either contained
    only one empty item or no item at all.
- Changes from version 0.6.0:
  + Support for Twitter Lists added.
  + Updated icons.
  + The last tweet that was selected in a list of tweets (e.g. the
    Main timeline or Replies) is now remembered when switching back
    and forth between pages.
  + The user can now set the maximum inline media size by
    Megabytes.
  + The Corebird sidebar can now be hidden.
  + The keyboard shortcuts for hiding/showing the toolbar, and
    composing a new tweet are now stored in GNOME gsettings.
  + Buttons are now aligned at the top of a tweet and will not
    obscure the tweet.
  + Shortcuts have been changed to require a double press of the
    key.
  + The User Profiles page now displays if the user is following
    you.
  + The User Profiles page now displays if the user is a verified
    user on twitter.
  + The position of corebird main windows is now persistent.
  + Accessibility in corebird is now improved. Notable improvements
    include fixes for uses utilizing screen readers. Special thanks
    to Peter Vágner for contributing these improvements.
  + Many other bugfixes and enhancements.
* Mon Dec 23 2013 dimstar@opensuse.org
- Initial package, version 0.5.
